/*
 * Proxy criteria for OpenGate
 * 
 * Copyright (c) Marco Polci
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * $Log: ProxyCriteria.cxx,v $
 * Revision 1.4  2002/04/09 15:19:21  roman_skvirsky
 * Test
 *
 * Revision 1.3  2002/03/16 10:50:40  roman_skvirsky
 * Bogus comments removed, enabled listening thread execution
 *
 * Revision 1.2  2002/03/15 19:03:43  roman_skvirsky
 *
 * Some newer versions added (for several files)
 *
 * Revision 1.3  2001/01/24 10:41:04  mpolci
 * Now if you want to proxy all calls you can set the "Internal Network Address" to "*" in
 * the config file. Now this is the default.
 *
 * Revision 1.2  2000/10/17 13:00:13  mpolci
 * File header and CVS log entry setup
 *
 *
 * Revision 1.0  2000/09/04 10:33
 * Initial revision
 *
 */

#include <ptlib.h>
#include <ptlib/svcproc.h>
#include "ProxyCriteria.h"

void ProxyCriteria::loadConfiguration( const PConfig & cfg )
{
   fProxyEnabled = cfg.GetBoolean( "Proxy", "Proxy Enabled", FALSE );


   fProxyInternal = cfg.GetBoolean( "Proxy", "Proxy Internal", FALSE );


   PString addr, mask;
   addr = cfg.GetString( "Proxy", "Internal Network Address", "*");
   mask = cfg.GetString( "Proxy", "Internal Network Mask", "255.255.255.255" );
   PSYSTEMLOG( Info, "Proxy enabled = " << fProxyEnabled << " addr = " << addr << " mask = " << mask << " for internal network " << fProxyInternal);
   netaddress = PIPSocket::Address( addr );
   netmask = PIPSocket::Address( mask );
   PSYSTEMLOG( Info, netaddress << "/" << netmask );
}

BOOL ProxyCriteria::proxyRequired( PIPSocket::Address ip1, PIPSocket::Address ip2 ) const
// Task: to check if the proxy must be enabled to allow comunications between these ip addresses.
{
	if ( fProxyEnabled ) {
		if ( netaddress == INADDR_ANY ) 
         		return TRUE;
      		else {
         		BOOL ip1internal = ( (ip1 & netmask) == netaddress ),
              		ip2internal = ( (ip2 & netmask) == netaddress );
//roman
 			if( fProxyInternal) { 
  				PSYSTEMLOG( Info, "ProxyCriteria: proxy internal network"  );  
  				//return (ip1internal && !ip2internal) || (!ip1internal && ip2internal) || (ip1internal && ip1internal);
				return TRUE;
 			} else 
         			return (ip1internal && !ip2internal) || (!ip1internal && ip2internal);
      		}
   	} else 

      	return FALSE;

}
